/*
 * analogue_clock_mode.cc
 *
 * Copyright (C) 2011 Tim Marston <tim@ed.am> and Dan Marston.
 *
 * This file is part of propeller-clock (hereafter referred to as "this
 * program"). See http://ed.am/dev/software/arduino/propeller-clock for more
 * information.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "analogue_clock_mode.h"
#include "config.h"
#include "Arduino.h"
#include "time.h"
#include "display.h"


AnalogueClockMode::AnalogueClockMode()
    :
    MinorMode( 2 )
{
}


void AnalogueClockMode::draw( int segment )
{
	bool draw_tick = segment && ( segment % ( NUM_SECOND_SEGMENTS * 5 ) == 0 ||
		segment == 1 || segment == NUM_SEGMENTS - 1 );
	bool draw_hour = segment == _hour_segment;
	bool draw_hour_side = 1 >=
		( abs( _hour_segment - segment ) + NUM_SEGMENTS ) % NUM_SEGMENTS;
		
//		( segment == ( _hour_segment + 1 ) % NUM_SEGMENTS ) ||
//		( segment == ( _hour_segment + NUM_SEGMENTS - 1 ) % NUM_SEGMENTS );
	bool draw_minute = segment == _minute_segment;
	bool draw_second = segment == _second_segment;

	// set the LEDs
	Display::led( 9, get_flavour() == 0 );
	Display::led( 8, draw_tick || draw_second );
	for( int a = 6; a <= 7; a++ )
		Display::led( a, draw_minute || draw_second );
	Display::led( 5, draw_minute || draw_second || draw_hour );
	for( int a = 0; a <= 4; a++ )
		Display::led( a, draw_minute || draw_second || draw_hour || draw_hour_side );
}


void AnalogueClockMode::draw_reset()
{
	Time &time = Time::get_instance();

	// calculate hand locations
	_hour_segment = ( time.get_hours() % 12 ) * 5 * NUM_SECOND_SEGMENTS +
		( 5 * NUM_SECOND_SEGMENTS * time.get_minutes() / 60 );
	_minute_segment = time.get_minutes() * NUM_SECOND_SEGMENTS +
		( NUM_SECOND_SEGMENTS * time.get_seconds() / 60 );
	_second_segment = time.get_seconds() * NUM_SECOND_SEGMENTS;
}
